pub struct FriendGroup<ProvidedBlockNumber, AccountId, Friends> {
pub friends: Friends,
pub friends_needed: u32,
pub inheritor: AccountId,
pub inheritance_delay: ProvidedBlockNumber,
pub inheritance_priority: InheritancePriority,
pub cancel_delay: ProvidedBlockNumber,
}Expand description
Group of friends that can initiate a recovery attempt for a specific lost account.
Fields
friends: FriendsList of friends that can initiate the recovery process. Always sorted.
friends_needed: u32The number of approving friends needed to recover an account.
inheritor: AccountIdThe account that will inherit full access to the lost account upon successful recovery.
inheritance_delay: ProvidedBlockNumberMinimum time that a recovery attempt must stay active before it can be finished.
Uses a provided block number to avoid possible clock skew of parachains.
inheritance_priority: InheritancePriorityUsed to resolve inheritance conflicts when multiple friend groups finish a recovery.
Higher-priority friend groups can replace the inheritor of a lower-priority group. For
example: you can set your family group as priority 0, your friends group as priority 1 and
co-workers as priority 2. This in combination with the inheritance_delay enables you to
ensure that the correct group receives the inheritance. See InheritancePriority for the
numeric convention.
cancel_delay: ProvidedBlockNumberThe delay since the last approval of an attempt before the attempt can be canceled.
It ensures that a malicious recoverer does not abuse the cancel_attempt call to dodge an
incoming slash from the lost account. They could otherwise monitor the TX pool and cancel
the attempt just in time for the slash transaction to fail. Now instead, the lost account
has at least cancel_delay provided blocks to slash the attempt.