referrerpolicy=no-referrer-when-downgrade

AttemptOf

Type Alias AttemptOf 

pub type AttemptOf<T> = Attempt<ProvidedBlockNumberOf<T>, ApprovalBitfieldOf<T>, AccountIdFor<T>>;
Attempt to recover an account.

Aliased Type

pub struct AttemptOf<T> {
    pub friend_group_index: u32,
    pub initiator: <T as Config>::AccountId,
    pub init_block: <<T as Config>::BlockNumberProvider as BlockNumberProvider>::BlockNumber,
    pub last_approval_block: <<T as Config>::BlockNumberProvider as BlockNumberProvider>::BlockNumber,
    pub approvals: Bitfield<<T as Config>::MaxFriendsPerConfig>,
}

Fields

friend_group_index: u32

Index of the friend group that initiated the attempt.

This will never be more than MAX_GROUPS_PER_ACCOUNT.

initiator: <T as Config>::AccountId

The account that initiated the attempt.

init_block: <<T as Config>::BlockNumberProvider as BlockNumberProvider>::BlockNumber

The block number when the attempt was initiated.

Note that this can be a foreign (ie Relay) block number.

last_approval_block: <<T as Config>::BlockNumberProvider as BlockNumberProvider>::BlockNumber

The block number when the last friend approved the attempt.

Note that this can be a foreign (ie Relay) block number.

approvals: Bitfield<<T as Config>::MaxFriendsPerConfig>

Bitfield tracking which friends approved.

Each bit corresponds to a friend in the friend_group.friends that has approved the attempt.