pub type AttemptTicketOf<T> = IdentifiedConsideration<AccountIdFor<T>, Footprint, <T as Config>::AttemptConsideration>;Expand description
Ticket for an attempt to recover an account.
Aliased Type
pub struct AttemptTicketOf<T> {
pub depositor: <T as Config>::AccountId,
pub ticket: Option<<T as Config>::AttemptConsideration>,
/* private fields */
}Fields
depositor: <T as Config>::AccountIdAccount that paid the storage deposit.
This is also the account that will receive the refund.
ticket: Option<<T as Config>::AttemptConsideration>Opaque ticket to track the payment of a deposit.