pub type InheritorTicketOf<T> = IdentifiedConsideration<AccountIdFor<T>, Footprint, <T as Config>::InheritorConsideration>;Expand description
Ticket for the inheritor of an account.
Aliased Type
pub struct InheritorTicketOf<T> {
pub depositor: <T as Config>::AccountId,
pub ticket: Option<<T as Config>::InheritorConsideration>,
/* private fields */
}Fields
depositor: <T as Config>::AccountIdAccount that paid the storage deposit.
This is also the account that will receive the refund.
ticket: Option<<T as Config>::InheritorConsideration>Opaque ticket to track the payment of a deposit.